@@ -2,8 +2,7 @@
    headers.h
 
    This file is part of GNU Anubis.
-   Copyright (C) 2001, 2002, 2003, 2004, 2005, 2007, 2008,
-   2009, 2010, 2011 The Anubis Team.
+   Copyright (C) 2001-2014 The Anubis Team.
 
    GNU Anubis is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -324,11 +323,6 @@ int stream_destroy (NET_STREAM *);
 /* main.c */
 void anubis (char *);
 
-/* setenv.c */
-#if !defined(HAVE_SETENV) && defined(HAVE_PUTENV)
-int setenv (const char *, const char *, int);
-#endif
-
 /* env.c */
 void get_options (int, char *[]);
 void get_homedir (char *, char *, int);
@@ -515,9 +509,8 @@ int check_socks_proxy (int, char *, unsigned int);
 /* tls.c */
 #ifdef USE_SSL
 void init_ssl_libs (void);
-NET_STREAM start_ssl_client (NET_STREAM str, const char *cafile, int verbose);
-NET_STREAM start_ssl_server (NET_STREAM str, const char *cafile,
-			     const char *cert, const char *key, int verbose);
+NET_STREAM start_ssl_client (NET_STREAM str, int verbose);
+NET_STREAM start_ssl_server (NET_STREAM str, int verbose);
 #endif /* USE_SSL */
 
 /* gpg.c */
@@ -581,7 +574,7 @@ enum anubis_db_mode
 				   only) */
 
 typedef int (*anubis_db_open_t) (void **d, ANUBIS_URL * url,
-				 enum anubis_db_mode mode, char **errp);
+				 enum anubis_db_mode mode, char const **errp);
 typedef int (*anubis_db_close_t) (void *d);
 typedef int (*anubis_db_io_t) (void *d, const char *key, ANUBIS_USER * rec,
 			       int *ecode);
@@ -598,7 +591,7 @@ int anubis_db_register (const char *dbid,
 			anubis_db_get_list_t _db_list,
 			anubis_db_strerror_t _db_strerror);
 int anubis_db_open (char *arg, enum anubis_db_mode mode, void **dptr,
-		    char **errp);
+		    char const **errp);
 int anubis_db_close (void **dptr);
 int anubis_db_get_record (void *dptr, const char *key, ANUBIS_USER * rec);
 int anubis_db_put_record (void *dptr, const char *key, ANUBIS_USER * rec);
